@@ -44,7 +44,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT License"
-__version__: str = "0.3.3"
+__version__: str = "0.4.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["setup"]
@@ -59,6 +59,7 @@ def setup(app: Sphinx) -> Dict[str, Any]:
 	:return:
 	"""
 
+	# Ensure dependencies are set up
 	app.setup_extension("sphinx.ext.viewcode")
 	app.setup_extension("sphinx_tabs.tabs")
 	app.setup_extension("sphinx-prompt")
@@ -134,4 +135,7 @@ def setup(app: Sphinx) -> Dict[str, Any]:
 
 	app.add_source_parser(CustomRSTParser, override=True)
 
-	return {"version": __version__, "parallel_read_safe": True}
+	return {
+			"version": __version__,
+			"parallel_read_safe": True,
+			}
